@@ -2,10 +2,10 @@
 # -*- perl -*-
 
 #
-# $Id: oo.t,v 1.2 1997/03/29 19:32:23 eserte Exp eserte $
+# $Id: test.pl,v 1.3 1997/11/28 18:41:01 eserte Exp $
 # Author: Slaven Rezic
 #
-# Copyright  1997 Slaven Rezic. All rights reserved.
+# Copyright (C) 1997 Slaven Rezic. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 #
@@ -20,7 +20,16 @@ use strict;
 $^W = 1;
 
 my $cache = new Netscape::Cache;
-die if !$cache;
+if (!$cache) {
+    die <<'EOF';
+Please edit test.pl
+Change the line
+    my $cache = new Netscape::Cache;
+to
+    my $cache = new Netscape::Cache(-cachedir => "/path/to/my/cachedir");
+and rerun the test.
+EOF
+}
 
 my($o, @url);
 while ($o = $cache->next_object) {
@@ -29,8 +38,12 @@ while ($o = $cache->next_object) {
 # sort by name
 @url = sort {$a->{'URL'} cmp $b->{'URL'}} @url;
 
-my $pager = $Config{'pager'} || 'more';
-open(OUT, "|$pager");
+if ($Netscape::Cache::OS_Type eq 'win') {
+    open(OUT, ">&STDOUT");
+} else {
+    my $pager = $Config{'pager'} || 'more';
+    open(OUT, "|$pager");
+}
 print OUT "Object oriented interface:\n";
 foreach (@url) {
     print OUT $_->{'URL'}, " ", scalar localtime $_->{'LAST_VISITED'}, "\n";
